@@ -1,6 +1,7 @@
 ENMevaluation <- setClass("ENMevaluation",
 					   slots=c(results='data.frame', 
 					   predictions='RasterStack',
+             models='list',
 					   partition.method='character',
 					   occ.pts='data.frame',
 					   occ.grp='numeric',
@@ -19,6 +20,7 @@ setMethod("show",
 		  		" ",  "Regularization multipliers: ", paste(unique(object@results[,3]), collapse=', '), '\n',
 		  		" ",  "@results     : data.frame of evaluation results", '\n',
 		  		" ",  "@predictions : RasterStack of model predictions", '\n',
+          " ",  "@models      : list of model objects", '\n',
 		  		" ",  "@occ.pts     : data.frame of occurrence coordinates", '\n',
 		  		" ",  "@occ.grp     : vector of bins for occurrence points", '\n',
 		  		" ",  "@bg.pts      : data.frame of background coordinates", '\n',
